//=============================================================================
// FLBasketball.
//=============================================================================
class FLBasketball extends ThrownProjectile;

var bool bAlreadyScored; // To prevent double-triple etc. scoring each time the ball hits the trigger
var bool bDoomedToDestroy; // To prevent using the basketball anywhere else but on the court
var Measurer MeasureActor;

function Timer()
{
	if(bDoomedToDestroy)
	{
		Destroy();
	}
}

simulated function Tick(float deltaTime)
{
	return;
}

simulated function TakeDamage(int Damage, Pawn instigatedBy, Vector HitLocation, Vector Momentum, name damageType)
{
	return;
}

simulated function Explode(vector HitLocation, vector HitNormal)
{
	return;
}

function Frob(Actor Frobber, Inventory frobWith)
{
	local FLBasketball4Player FLB4P;
	if (!bDoomedToDestroy)
	{
		FLB4P = Spawn(Class'FLBasketball4Player',Frobber,,Location,Rotation);
		DeusExPlayer(Frobber).FrobTarget = FLB4P;
		DeusExPlayer(Frobber).GrabDecoration();
		Super.Frob(Frobber, frobWith);
		MeasureActor.Destroy();
		Destroy();
	}
	else 
	{
		return;
	}
}

event ZoneChange (ZoneInfo NewZone)
{
	Super.ZoneChange(NewZone);
	if (NewZone.IsA('BasketballZone'))
	{
		bDoomedToDestroy = False;
		SetTimer(0, False);
	}
	else
	{
		bDoomedToDestroy = True;
		SetTimer(15, False);
	}
}

auto simulated state Flying
{
	simulated function HitWall(vector HitNormal, actor HitWall)
	{
		local float speed;

		if (DeusExPlayer(HitWall) != None && !bDoomedToDestroy && DeusExPlayer(HitWall).inHand == None && DeusExPlayer(HitWall).carriedDecoration == None)
		{
			DeusExPlayer(HitWall).FrobTarget = self;
			Frob(DeusExPlayer(HitWall), DeusExPlayer(HitWall).inHand);
		}
	 
		Velocity = 0.8*((Velocity dot HitNormal) * HitNormal * (-2.0) + Velocity);
		speed = VSize(Velocity);
		bFixedRotationDir = True;
		RotationRate = RotRand(False);
		if ((speed > 0) && (speed < 30) && (HitNormal.Z > 0.7))
		{
			SetPhysics(PHYS_None, HitWall);
			if (Physics == PHYS_None)
				bFixedRotationDir = False;
		}
	
		if (HitWall.IsA('Mover'))
		{
			HitWall.TakeDamage(speed/58, Pawn(Owner), HitWall.Location, MomentumTransfer*Normal(Velocity), 'Shot');
		}
		
		else if (speed > 30)
		{	
			if ((FRand() >= 0.75) && (FRand() < 1.0))
			{
				PlaySound(sound'Bounce1', SLOT_None, 3);
			}
			else if ((FRand() >= 0.5) && (FRand() < 0.75))
			{
				PlaySound(sound'Bounce2', SLOT_None, 3);	
			}
			else
			{
				PlaySound(sound'Bounce3', SLOT_None, 3);	
			}
		}
	}
}

simulated function BeginPlay()
{
	local Measurer MA;
	if (Region.Zone.IsA('BasketballZone'))
	{
		bDoomedToDestroy = False;
		SetTimer(0, False);
	}
	else
	{
		bDoomedToDestroy = True;
		SetTimer(15, False);
	}
	if (MeasureActor == None)
	{
		MA = Spawn(class'Measurer',,, Location);
		MeasureActor = MA;
	}
	Super.BeginPlay();
}

defaultproperties
{
	bDoomedToDestroy=False
  bDisabled=True
  bExplodes=False
	bBlood=False
	bEmitDanger=False
	bIgnoresNanoDefense=True
	ItemName="Basketball"
	LifeSpan=0.00
	bDirectional=False
	Mesh=LodMesh'FLBasketball'
	DrawScale=0.70
	CollisionRadius=10.00
	CollisionHeight=10.00
	bBlockActors=True
	bBlockPlayers=True
	Mass=8.00
	Buoyancy=10.00
}
